'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isProxyEvent = isProxyEvent;
exports.getEventNames = getEventNames;
exports.removeNonProxyEvents = removeNonProxyEvents;

var _constants = require('./constants');

// Test whether an event is a proxy or not
function isProxyEvent(name) {
  return name.indexOf(_constants.UNIQUE) === 0;
}

// get the registered events for a given emitter. Backwards-compatible with old Node versions.
function getEventNames(emitter) {
  // eventNames was added in v6.0.0, use it if possible.
  if (emitter.eventNames && typeof emitter.eventNames === 'function') {
    return emitter.eventNames();
  }
  // if not...well, here's the fallback.
  return Object.keys(emitter._events);
}

function removeNonProxyEvents(emitter) {
  getEventNames(emitter).filter(function (name) {
    return !isProxyEvent(name);
  }).forEach(function (name) {
    emitter.removeAllListeners(name);
  });
}